# arpes.corrections.cycle module

**arpes.corrections.cycle.apply\_cycle\_fermi\_edge\_correction(data:
Union\[xarray.core.dataarray.DataArray, xarray.core.dataset.Dataset\],
energy\_range=None, shift=True)**

**arpes.corrections.cycle.build\_cycle\_fermi\_edge\_correction(data:
Union\[xarray.core.dataarray.DataArray, xarray.core.dataset.Dataset\],
energy\_range=None)**
